#!/bin/bash

LSDB_HOME=$(dirname $0)

syslog_name=
if [ -f /etc/SuSE-release ]; then
    syslog_name='syslog'
else
    syslog_name='syslog-ng'
fi

COMMAND=$1

$LSDB_HOME/configs/manage_pg_config.sh $COMMAND .i18n $LSDB_HOME/configs /var/lib/pgsql

case "$COMMAND" in
    'install')
        service postgresql status >/dev/null
        if [ $? -gt 0 ]; then
            service postgresql start || exit 1
            sleep 1
        fi

        echo -n "Creating database : "
        $2/create_database.sh | tee $2/db.create.log 2>&1 && echo "[  OK  ]" || echo "[FAILED]"
        ;;
    'upgrade')
        service postgresql status >/dev/null
        if [ $? -gt 0 ]; then
            service postgresql start || exit 1
            sleep 1
        fi

        echo "Database upgrade start. Please wait"
        echo -n "Upgrading database : "
        $2/upgrade.sh | tee $2/db.update.log 2>&1 && echo "[  OK  ]" || echo "[FAILED]"
        ;;
    'renew')
        ;;

    'uninstall')
        service postgresql status >/dev/null
        if [ $? -gt 0 ]; then
            service postgresql start || exit 1
        fi

        if [ $(find /var/run -name "syslog-ng.pid") ];
        then
            service $syslog_name stop
            echo -n "Destroying database : "
            $2/destroy_database.sh | tee $2/db.create.log 2>&1 && echo "[  OK  ]" || echo "[FAILED]"
            service $syslog_name start
        else
            echo -n "Destroying database : "
            $2/destroy_database.sh | tee $2/db.create.log 2>&1 && echo "[  OK  ]" || echo "[FAILED]"
        fi

        userdel -r op5lsu
        ;;

    *)
        echo "Bad parameter"
        ;;
esac

$LSDB_HOME/configs/manage_pg_config.sh $COMMAND pg_hba.conf $LSDB_HOME/configs /var/lib/pgsql/data

service postgresql status >/dev/null
if [ $? -eq 0 ]; then
    service postgresql stop
fi
service postgresql start
